@@ -154,27 +154,29 @@ module Prawn
           raise ArgumentError, "unknown color space: '#{color_space}'"
         end
 
-        operator = case type
-                   when :fill
-                     'cs'
-                   when :stroke
-                     'CS'
-                   else
-                     raise ArgumentError, "unknown type '#{type}'"
-                   end
+        operator =
+          case type
+          when :fill
+            'cs'
+          when :stroke
+            'CS'
+          else
+            raise ArgumentError, "unknown type '#{type}'"
+          end
 
         renderer.add_content "/#{color_space} #{operator}"
       end
 
       def set_color(type, color, options = {})
-        operator = case type
-                   when :fill
-                     'scn'
-                   when :stroke
-                     'SCN'
-                   else
-                     raise ArgumentError, "unknown type '#{type}'"
-                   end
+        operator =
+          case type
+          when :fill
+            'scn'
+          when :stroke
+            'SCN'
+          else
+            raise ArgumentError, "unknown type '#{type}'"
+          end
 
         if options[:pattern]
           set_color_space type, :Pattern
