@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # text/formatted/rectangle.rb : Implements text boxes with formatted text
 #
 # Copyright February 2010, Daniel Nelson. All Rights Reserved.
@@ -220,11 +222,12 @@ module Prawn
                   shrink_to_fit(text) if @overflow == :shrink_to_fit
                   process_vertical_alignment(text)
                   @inked = true unless flags[:dry_run]
-                  unprinted_text = if @rotate != 0 && @inked
-                                     render_rotated(text)
-                                   else
-                                     wrap(text)
-                                   end
+                  unprinted_text =
+                    if @rotate != 0 && @inked
+                      render_rotated(text)
+                    else
+                      wrap(text)
+                    end
                   @inked = false
                 end
               end
@@ -246,6 +249,7 @@ module Prawn
         #
         def height
           return 0 if @baseline_y.nil? || @descender.nil?
+
           (@baseline_y - @descender).abs
         end
 
@@ -262,11 +266,15 @@ module Prawn
           when :right
             x = @at[0] + @width - line_width
           when :justify
-            x = if @direction == :ltr
-                  @at[0]
-                else
-                  @at[0] + @width - line_width
-                end
+            x =
+              if @direction == :ltr
+                @at[0]
+              else
+                @at[0] + @width - line_width
+              end
+          else
+            raise ArgumentError,
+              'align must be one of :left, :right, :center or :justify symbols'
           end
 
           x += accumulated_width
@@ -284,13 +292,15 @@ module Prawn
             @document.word_spacing(word_spacing) do
               if @draw_text_callback
                 @draw_text_callback.call(
-                  fragment.text, at: [x, y],
-                                 kerning: @kerning
+                  fragment.text,
+                  at: [x, y],
+                  kerning: @kerning
                 )
               else
                 @document.draw_text!(
-                  fragment.text, at: [x, y],
-                                 kerning: @kerning
+                  fragment.text,
+                  at: [x, y],
+                  kerning: @kerning
                 )
               end
             end
@@ -334,23 +344,24 @@ module Prawn
 
         # @private
         def self.inherited(base)
+          super
           extensions.each { |e| base.extensions << e }
         end
 
         def valid_options
-          PDF::Core::Text::VALID_OPTIONS + [
-            :at,
-            :height, :width,
-            :align, :valign,
-            :rotate, :rotate_around,
-            :overflow, :min_font_size,
-            :disable_wrap_by_char,
-            :leading, :character_spacing,
-            :mode, :single_line,
-            :document,
-            :direction,
-            :fallback_fonts,
-            :draw_text_callback
+          PDF::Core::Text::VALID_OPTIONS + %i[
+            at
+            height width
+            align valign
+            rotate rotate_around
+            overflow min_font_size
+            disable_wrap_by_char
+            leading character_spacing
+            mode single_line
+            document
+            direction
+            fallback_fonts
+            draw_text_callback
           ]
         end
 
@@ -365,7 +376,7 @@ module Prawn
         end
 
         def original_text
-          @original_array.collect(&:dup)
+          @original_array.map(&:dup)
         end
 
         def original_text=(formatted_text)
@@ -496,6 +507,7 @@ module Prawn
               @vertical_alignment_processed
             return
           end
+
           @vertical_alignment_processed = true
 
           return if @vertical_align == :top
@@ -587,6 +599,7 @@ module Prawn
 
         def draw_fragment_overlay_link(fragment)
           return unless fragment.link
+
           box = fragment.absolute_bounding_box
           @document.link_annotation(
             box,
@@ -601,6 +614,7 @@ module Prawn
 
         def draw_fragment_overlay_anchor(fragment)
           return unless fragment.anchor
+
           box = fragment.absolute_bounding_box
           @document.link_annotation(
             box,
@@ -611,6 +625,7 @@ module Prawn
 
         def draw_fragment_overlay_local(fragment)
           return unless fragment.local
+
           box = fragment.absolute_bounding_box
           @document.link_annotation(
             box,
