@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # transformation_stack.rb : Stores the transformations that have been applied to
 # the document
 #
@@ -7,7 +9,7 @@
 
 require 'matrix'
 
-# rubocop: disable Metrics/ParameterLists
+# rubocop: disable Metrics/ParameterLists, Naming/MethodParameterName
 module Prawn
   module TransformationStack
     def add_to_transformation_stack(a, b, c, d, e, f)
@@ -21,7 +23,7 @@ module Prawn
     end
 
     def restore_transformation_stack
-      @transformation_stack.pop if @transformation_stack
+      @transformation_stack&.pop
     end
 
     def current_transformation_matrix_with_translation(x = 0, y = 0)
@@ -39,3 +41,4 @@ module Prawn
     end
   end
 end
+# rubocop: enable Metrics/ParameterLists, Naming/MethodParameterName
