@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Pass an image path to the <code>:background</code> option and it will be used
 # as the background for all pages.
 # This option can only be used on document creation.
@@ -14,10 +16,14 @@ Prawn::Document.generate(filename, background: img, margin: 100) do
   move_down font.height * 2
 
   text 'Here is my text explaning this report. ' * 20,
-    size: 12, align: :left, leading: 2
+    size: 12,
+    align: :left,
+    leading: 2
 
   move_down font.height
 
   text "I'm using a soft background. " * 40,
-    size: 12, align: :left, leading: 2
+    size: 12,
+    align: :left,
+    leading: 2
 end
