@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # The cap style defines how the edge of a line or curve will be drawn. There are
 # three types: <code>:butt</code> (the default), <code>:round</code> and
 # <code>:projecting_square</code>
@@ -18,7 +20,7 @@ Prawn::ManualBuilder::Example.generate(filename) do
 
   self.line_width = 25
 
-  [:butt, :round, :projecting_square].each_with_index do |cap, i|
+  %i[butt round projecting_square].each_with_index do |cap, i|
     self.cap_style = cap
 
     y = 250 - i * 100
