@@ -1,12 +1,12 @@
-# encoding: utf-8
-#
+# frozen_string_literal: true
+
 # Prawn manual how to read this manual page.
 
-require_relative "example_helper"
+require_relative 'example_helper'
 
 filename = File.basename(__FILE__).gsub('.rb', '.pdf')
 Prawn::ManualBuilder::Example.generate(filename) do
-  header("How to read this manual")
+  header('How to read this manual')
 
   prose <<-END_TEXT
   This manual is a collection of examples categorized by theme and organized from the least to the most complex. While it covers most of the common use cases it is not a comprehensive guide.
@@ -21,12 +21,12 @@ Prawn::ManualBuilder::Example.generate(filename) do
   END_TEXT
 
   move_down(Prawn::ManualBuilder::Example::BOX_MARGIN)
-  header("Reading the examples")
+  header('Reading the examples')
 
   prose <<-END_TEXT
   The title of each example is the relative path from the Prawn source manual/ folder.
 
-  The first body of text is the introductory text for the example. Generaly it is a short description of the features illustrated by the example.
+  The first body of text is the introductory text for the example. Generally it is a short description of the features illustrated by the example.
 
   Next comes the example source code block in fixed width font.
 
