@@ -16,12 +16,15 @@ Prawn::ManualBuilder::Example.generate(filename) do
     %i[top center bottom].each do |vposition|
       text "Image vertically aligned to the #{vposition}.", valign: vposition
       image "#{Prawn::DATADIR}/images/stef.jpg",
-        position: 250, vposition: vposition
+        position: 250,
+        vposition: vposition
     end
 
     text_box 'The next image has a 100 point offset from the top boundary',
-      at: [bounds.width - 110, bounds.top - 10], width: 100
+      at: [bounds.width - 110, bounds.top - 10],
+      width: 100
     image "#{Prawn::DATADIR}/images/stef.jpg",
-      position: :right, vposition: 100
+      position: :right,
+      vposition: 100
   end
 end
