@@ -15,10 +15,10 @@ Prawn::ManualBuilder::Example.generate(filename) do
   define_grid(columns: 5, rows: 8, gutter: 10)
 
   grid([5, 0], [7, 1]).bounding_box do
-    text "Adding some content to this multi_box.\n" + ' _ ' * 200
+    text "Adding some content to this multi_box.\n#{' _ ' * 200}"
   end
 
   grid(6, 3).bounding_box do
-    text "Just a little snippet here.\n" + ' _ ' * 10
+    text "Just a little snippet here.\n#{' _ ' * 10}"
   end
 end
