@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Examples for using grid layouts.
 
 require_relative '../example_helper'
@@ -9,11 +11,11 @@ Prawn::ManualBuilder::Example.generate('layout.pdf', page_size: 'FOLIO') do
     p.example 'content'
 
     p.intro do
-      prose <<-END
+      prose <<-TEXT
         Prawn has support for two-dimensional grid based layouts out of the box.
 
         The examples show:
-      END
+      TEXT
 
       list(
         'How to define the document grid',
