@@ -1,5 +1,5 @@
-# encoding: utf-8
-#
+# frozen_string_literal: true
+
 # The document outline tree is the set of links used to navigate through the
 # various document sections and pages.
 #
@@ -23,9 +23,8 @@
 # <code>section</code> and <code>page</code> may also be used without the
 # <code>define</code> method but they will need to instantiate the
 # <code>outline</code> object every time.
-#
-require File.expand_path(File.join(File.dirname(__FILE__),
-                                   %w[.. example_helper]))
+
+require_relative '../example_helper'
 
 filename = File.basename(__FILE__).gsub('.rb', '.pdf')
 Prawn::ManualBuilder::Example.generate(filename) do
@@ -36,32 +35,32 @@ Prawn::ManualBuilder::Example.generate(filename) do
   end
 
   outline.define do
-    section("Section 1", :destination => 1) do
-      page :title => "Page 2", :destination => 2
-      page :title => "Page 3", :destination => 3
+    section('Section 1', destination: 1) do
+      page title: 'Page 2', destination: 2
+      page title: 'Page 3', destination: 3
     end
 
-    section("Section 2", :destination => 4) do
-      page :title => "Page 5", :destination => 5
+    section('Section 2', destination: 4) do
+      page title: 'Page 5', destination: 5
 
-      section("Subsection 2.1", :destination => 6, :closed => true) do
-        page :title => "Page 7", :destination => 7
+      section('Subsection 2.1', destination: 6, closed: true) do
+        page title: 'Page 7', destination: 7
       end
     end
   end
 
   # Outside of the define block
-  outline.section("Section 3", :destination => 8) do
-    outline.page :title => "Page 9", :destination => 9
+  outline.section('Section 3', destination: 8) do
+    outline.page title: 'Page 9', destination: 9
   end
 
-  outline.page :title => "Page 10", :destination => 10
+  outline.page title: 'Page 10', destination: 10
 
   # Section and Pages without links. While a section without a link may be
   # useful to group some pages, a page without a link is useless
-  outline.update do  # update is an alias to define
-    section("Section without link") do
-      page :title => "Page without link"
+  outline.update do # update is an alias to define
+    section('Section without link') do
+      page title: 'Page without link'
     end
   end
 end
