@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Prawn enables the declaration of fallback fonts for those glyphs that may not
 # be present in the desired font. Use the <code>:fallback_fonts</code> option
 # with any of the text or text box methods, or set fallback_fonts document-wide.
@@ -24,7 +26,7 @@ Prawn::ManualBuilder::Example.generate(filename) do
       'to right.' \
       "\n\n" \
       "hello ƒ 你好\n再见 ƒ goodbye",
-      fallback_fonts: ['Times-Roman', 'Kai']
+      fallback_fonts: %w[Times-Roman Kai]
     )
   end
   move_down 20
@@ -34,6 +36,6 @@ Prawn::ManualBuilder::Example.generate(filename) do
       { text: 'Fallback fonts can even override' },
       { text: 'fragment fonts (你好)', font: 'Times-Roman' }
     ],
-    fallback_fonts: ['Times-Roman', 'Kai']
+    fallback_fonts: %w[Times-Roman Kai]
   )
 end
