@@ -41,25 +41,30 @@ Prawn::ManualBuilder::Example.generate(filename) do
 
     def render_in_front(fragment)
       @document.stroke_polygon(
-        fragment.top_left, fragment.top_right,
-        fragment.bottom_right, fragment.bottom_left
+        fragment.top_left,
+        fragment.top_right,
+        fragment.bottom_right,
+        fragment.bottom_left
       )
 
-      @document.fill_circle(fragment.top_left,     @radius)
-      @document.fill_circle(fragment.top_right,    @radius)
+      @document.fill_circle(fragment.top_left, @radius)
+      @document.fill_circle(fragment.top_right, @radius)
       @document.fill_circle(fragment.bottom_right, @radius)
-      @document.fill_circle(fragment.bottom_left,  @radius)
+      @document.fill_circle(fragment.bottom_left, @radius)
     end
   end
 
   highlight = HighlightCallback.new(color: 'ffff00', document: self)
   border = ConnectedBorderCallback.new(radius: 2.5, document: self)
 
-  formatted_text [
-    { text: 'hello', callback: highlight },
-    { text: '     ' },
-    { text: 'world', callback: border },
-    { text: '     ' },
-    { text: 'hello world', callback: [highlight, border] }
-  ], size: 20
+  formatted_text(
+    [
+      { text: 'hello', callback: highlight },
+      { text: '     ' },
+      { text: 'world', callback: border },
+      { text: '     ' },
+      { text: 'hello world', callback: [highlight, border] }
+    ],
+    size: 20
+  )
 end
