@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Prawn strips all whitespace from the beginning and the end of strings so there
 # are two ways to indent paragraphs:
 #
@@ -17,14 +19,13 @@ Prawn::ManualBuilder::Example.generate(filename) do
     "\n#{Prawn::Text::NBSP * 10}" + 'This one will with NBSP. ' * 10
 
   move_down 20
-  text 'This paragraph will be indented. ' * 10 +
-    "\n" + 'This one will too. ' * 10,
+  text "#{'This paragraph will be indented. ' * 10}\n#{'This one will too. ' * 10}",
     indent_paragraphs: 60
 
   move_down 20
 
   text 'FROM RIGHT TO LEFT:'
-  text 'This paragraph will be indented. ' * 10 +
-    "\n" + 'This one will too. ' * 10,
-    indent_paragraphs: 60, direction: :rtl
+  text "#{'This paragraph will be indented. ' * 10}\n#{'This one will too. ' * 10}",
+    indent_paragraphs: 60,
+    direction: :rtl
 end
