@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Registering font families will help you when you want to use a font over and
 # over or if you would like to take advantage of the <code>:style</code> option
 # of the text methods and the <code>b</code> and <code>i</code> tags when using
@@ -10,7 +12,7 @@ require_relative '../example_helper'
 
 filename = File.basename(__FILE__).gsub('.rb', '.pdf')
 Prawn::ManualBuilder::Example.generate(filename) do
-  # Registering a single TTF font
+  # Registering a single external font
   font_families.update(
     'DejaVu Sans' => {
       normal: "#{Prawn::DATADIR}/fonts/DejaVuSans.ttf"
@@ -41,7 +43,7 @@ Prawn::ManualBuilder::Example.generate(filename) do
     inline_format: true
   move_down 20
 
-  [:bold, :bold_italic, :italic, :normal].each do |style|
+  %i[bold bold_italic italic normal].each do |style|
     text "Using the #{style} style option.",
       style: style
     move_down 10
