@@ -31,7 +31,7 @@ Prawn::ManualBuilder::Example.generate(filename) do
     text 'You can override the document direction.', direction: :ltr
     move_down 20
 
-    formatted_text [
+    formatted_text([
       { text: '更可怕的是，同质化竞争对手可以按照' },
       { text: 'URL', direction: :ltr },
       { text: '中后面这个' },
@@ -40,15 +40,15 @@ Prawn::ManualBuilder::Example.generate(filename) do
       { text: 'DB', direction: :ltr },
       { text: '中的内容，写个小爬虫把你的页面上的关键信息顺次爬下来也不是什么'\
         '难事，这样的话，你就非常被动了。' }
-    ]
+    ])
     move_down 20
 
-    formatted_text [
+    formatted_text([
       { text: '更可怕的是，同质化竞争对手可以按照' },
-      { text: 'this',  direction: :ltr },
+      { text: 'this', direction: :ltr },
       { text: "won't", direction: :ltr, size: 24 },
-      { text: 'work',  direction: :ltr },
+      { text: 'work', direction: :ltr },
       { text: '中的内容，写个小爬虫把你的页面上的关键信息顺次爬下来也不是什么难事' }
-    ]
+    ])
   end
 end
