@@ -21,14 +21,19 @@ Prawn::ManualBuilder::Example.generate(filename) do
   stroke_rectangle [0, y], width, height
   text_box(
     'This text was not rotated',
-    at: [0, y], width: width, height: height
+    at: [0, y],
+    width: width,
+    height: height
   )
 
   stroke_rectangle [0, y - 100], width, height
   text_box(
     'This text was rotated around the center',
-    at: [0, y - 100], width: width, height: height,
-    rotate: angle, rotate_around: :center
+    at: [0, y - 100],
+    width: width,
+    height: height,
+    rotate: angle,
+    rotate_around: :center
   )
 
   %i[lower_left upper_left lower_right upper_right]
