@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # The <code>text_box</code> method accepts both <code>:width</code> and
 # <code>:height</code> options. So what happens if the text doesn't fit the box?
 #
@@ -24,11 +26,12 @@ Prawn::ManualBuilder::Example.generate(filename) do
   text string
 
   y_position = cursor - 20
-  [:truncate, :expand, :shrink_to_fit].each_with_index do |mode, i|
-    text_box string, at: [i * 150, y_position],
-                     width: 100,
-                     height: 50,
-                     overflow: mode
+  %i[truncate expand shrink_to_fit].each_with_index do |mode, i|
+    text_box string,
+      at: [i * 150, y_position],
+      width: 100,
+      height: 50,
+      overflow: mode
   end
 
   string = 'If the box is too small for the text, :shrink_to_fit ' \
@@ -38,10 +41,11 @@ Prawn::ManualBuilder::Example.generate(filename) do
   text string
   y_position = cursor - 20
   [nil, 8, 10, 12].each_with_index do |value, index|
-    text_box string, at: [index * 150, y_position],
-                     width: 50,
-                     height: 50,
-                     overflow: :shrink_to_fit,
-                     min_font_size: value
+    text_box string,
+      at: [index * 150, y_position],
+      width: 50,
+      height: 50,
+      overflow: :shrink_to_fit,
+      min_font_size: value
   end
 end
