@@ -1,7 +1,6 @@
-puts "Prawn specs: Running on Ruby Version: #{RUBY_VERSION}"
+# frozen_string_literal: true
 
-require 'bundler'
-Bundler.setup
+puts "Prawn specs: Running on Ruby Version: #{RUBY_VERSION}"
 
 if ENV['COVERAGE']
   require 'simplecov'
@@ -13,7 +12,7 @@ end
 require_relative '../lib/prawn'
 
 Prawn.debug = true
-Prawn::Font::AFM.hide_m17n_warning = true
+Prawn::Fonts::AFM.hide_m17n_warning = true
 
 require 'rspec'
 require 'pdf/reader'
@@ -21,7 +20,7 @@ require 'pdf/inspector'
 
 # Requires supporting ruby files with custom matchers and macros, etc,
 # in spec/extensions/ and its subdirectories.
-Dir[File.dirname(__FILE__) + '/extensions/**/*.rb'].each { |f| require f }
+Dir[File.join(__dir__, 'extensions', '**', '*.rb')].sort.each { |f| require f }
 
 RSpec.configure do |config|
   config.include EncodingHelpers
@@ -42,8 +41,8 @@ RSpec::Matchers.define :have_parseable_xobjects do
 end
 
 # Make some methods public to assist in testing
-module Prawn
-  module Graphics
-    public :map_to_absolute
-  end
-end
+# module Prawn
+#   module Graphics
+#     public :map_to_absolute
+#   end
+# end
